package com.sun.java.swing.plaf.windows;

import javax.swing.JInternalFrame;
import javax.swing.plaf.basic.BasicGraphicsUtils;
import javax.swing.border.LineBorder;
import javax.swing.JToolBar;
import javax.swing.SwingConstants;
import java.awt.Insets;
import java.awt.Graphics;
import java.awt.Component;
import java.awt.Color;
import javax.swing.plaf.UIResource;
import javax.swing.border.AbstractBorder;
import javax.swing.BorderFactory;
import javax.swing.plaf.basic.BasicBorders;
import javax.swing.UIDefaults;
import javax.swing.plaf.BorderUIResource;
import javax.swing.border.EmptyBorder;
import javax.swing.UIManager;
import javax.swing.border.Border;

public class WindowsBorders
{
    public WindowsBorders() {
    }
    
    public static Border getProgressBarBorder() {
        UIDefaults lookAndFeelDefaults = UIManager.getLookAndFeelDefaults();
        return new BorderUIResource.CompoundBorderUIResource(new WindowsBorders.ProgressBarBorder(lookAndFeelDefaults.getColor("ProgressBar.shadow"), lookAndFeelDefaults.getColor("ProgressBar.highlight")), new EmptyBorder(1, 1, 1, 1));
    }
    
    public static Border getToolBarBorder() {
        UIDefaults lookAndFeelDefaults = UIManager.getLookAndFeelDefaults();
        return new WindowsBorders.ToolBarBorder(lookAndFeelDefaults.getColor("ToolBar.shadow"), lookAndFeelDefaults.getColor("ToolBar.highlight"));
    }
    
    public static Border getFocusCellHighlightBorder() {
        return new WindowsBorders.ComplementDashedBorder();
    }
    
    public static Border getTableHeaderBorder() {
        UIDefaults lookAndFeelDefaults = UIManager.getLookAndFeelDefaults();
        return new BorderUIResource.CompoundBorderUIResource(new BasicBorders.ButtonBorder(lookAndFeelDefaults.getColor("Table.shadow"), lookAndFeelDefaults.getColor("Table.darkShadow"), lookAndFeelDefaults.getColor("Table.light"), lookAndFeelDefaults.getColor("Table.highlight")), new BasicBorders.MarginBorder());
    }
    
    public static Border getInternalFrameBorder() {
        UIDefaults lookAndFeelDefaults = UIManager.getLookAndFeelDefaults();
        return new BorderUIResource.CompoundBorderUIResource(BorderFactory.createBevelBorder(0, lookAndFeelDefaults.getColor("InternalFrame.borderColor"), lookAndFeelDefaults.getColor("InternalFrame.borderHighlight"), lookAndFeelDefaults.getColor("InternalFrame.borderDarkShadow"), lookAndFeelDefaults.getColor("InternalFrame.borderShadow")), new WindowsBorders.InternalFrameLineBorder(lookAndFeelDefaults.getColor("InternalFrame.activeBorderColor"), lookAndFeelDefaults.getColor("InternalFrame.inactiveBorderColor"), lookAndFeelDefaults.getInt("InternalFrame.borderWidth")));
    }
    
    public static class ProgressBarBorder extends AbstractBorder implements UIResource
    {
        protected Color shadow;
        protected Color highlight;
        
        public ProgressBarBorder(Color shadow, Color highlight) {
            this.highlight = highlight;
            this.shadow = shadow;
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            graphics.setColor(this.shadow);
            graphics.drawLine(n, n2, n3 - 1, n2);
            graphics.drawLine(n, n2, n, n4 - 1);
            graphics.setColor(this.highlight);
            graphics.drawLine(n, n4 - 1, n3 - 1, n4 - 1);
            graphics.drawLine(n3 - 1, n2, n3 - 1, n4 - 1);
        }
        
        @Override
        public Insets getBorderInsets(Component component, Insets insets) {
            insets.set(1, 1, 1, 1);
            return insets;
        }
    }
    
    public static class ToolBarBorder extends AbstractBorder implements UIResource, SwingConstants
    {
        protected Color shadow;
        protected Color highlight;
        
        public ToolBarBorder(Color shadow, Color highlight) {
            this.highlight = highlight;
            this.shadow = shadow;
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            if (!(component instanceof JToolBar)) {
                return;
            }
            graphics.translate(n, n2);
            XPStyle xp = XPStyle.getXP();
            if (xp != null) {
                Border border = xp.getBorder(component, TMSchema.Part.TP_TOOLBAR);
                if (border != null) {
                    border.paintBorder(component, graphics, 0, 0, n3, n4);
                }
            }
            if (((JToolBar)component).isFloatable()) {
                int n5 = ((JToolBar)component).getOrientation() == 1;
                if (xp != null) {
                    XPStyle.Skin skin = xp.getSkin(component, n5 ? TMSchema.Part.RP_GRIPPERVERT : TMSchema.Part.RP_GRIPPER);
                    int width;
                    int height;
                    int n6;
                    int n7;
                    if (!(n5 == 0)) {
                        n6 = 0;
                        n7 = 2;
                        width = n3 - 1;
                        height = skin.getHeight();
                    }
                    else {
                        width = skin.getWidth();
                        height = n4 - 1;
                        n6 = (component.getComponentOrientation().isLeftToRight() ? 2 : (n3 - width - 2));
                        n7 = 0;
                    }
                    skin.paintSkin(graphics, n6, n7, width, height, TMSchema.State.NORMAL);
                }
                else if (n5 == 0) {
                    if (component.getComponentOrientation().isLeftToRight()) {
                        graphics.setColor(this.shadow);
                        graphics.drawLine(4, 3, 4, n4 - 4);
                        graphics.drawLine(4, n4 - 4, 2, n4 - 4);
                        graphics.setColor(this.highlight);
                        graphics.drawLine(2, 3, 3, 3);
                        graphics.drawLine(2, 3, 2, n4 - 5);
                    }
                    else {
                        graphics.setColor(this.shadow);
                        graphics.drawLine(n3 - 3, 3, n3 - 3, n4 - 4);
                        graphics.drawLine(n3 - 4, n4 - 4, n3 - 4, n4 - 4);
                        graphics.setColor(this.highlight);
                        graphics.drawLine(n3 - 5, 3, n3 - 4, 3);
                        graphics.drawLine(n3 - 5, 3, n3 - 5, n4 - 5);
                    }
                }
                else {
                    graphics.setColor(this.shadow);
                    graphics.drawLine(3, 4, n3 - 4, 4);
                    graphics.drawLine(n3 - 4, 2, n3 - 4, 4);
                    graphics.setColor(this.highlight);
                    graphics.drawLine(3, 2, n3 - 4, 2);
                    graphics.drawLine(3, 2, 3, 3);
                }
            }
            graphics.translate(-n, -n2);
            return;
        }
        
        @Override
        public Insets getBorderInsets(Component component, Insets insets) {
            insets.set(1, 1, 1, 1);
            if (!(component instanceof JToolBar)) {
                return insets;
            }
            if (((JToolBar)component).isFloatable()) {
                int left = (XPStyle.getXP() != null) ? 12 : 9;
                if (((JToolBar)component).getOrientation() == 0) {
                    if (component.getComponentOrientation().isLeftToRight()) {
                        insets.left = left;
                    }
                    else {
                        insets.right = left;
                    }
                }
                else {
                    insets.top = left;
                }
            }
            return insets;
        }
    }
    
    public static class DashedBorder extends LineBorder implements UIResource
    {
        public DashedBorder(Color color) {
            super(color);
        }
        
        public DashedBorder(Color color, int thickness) {
            super(color, thickness);
        }
        
        @Override
        public void paintBorder(Component component, Graphics g, int n, int n2, int n3, int n4) {
            Color color = g.getColor();
            g.setColor(this.lineColor);
            for (int i = 0; i < this.thickness; ++i) {
                BasicGraphicsUtils.drawDashedRect(g, n + i, n2 + i, n3 - i - i, n4 - i - i);
            }
            g.setColor(color);
        }
    }
    
    static class ComplementDashedBorder extends LineBorder implements UIResource
    {
        private Color origColor;
        private Color paintColor;
        
        public ComplementDashedBorder() {
            super(null);
        }
        
        @Override
        public void paintBorder(Component component, Graphics g, int x, int y, int width, int height) {
            Color background = component.getBackground();
            if (this.origColor != background) {
                this.origColor = background;
                this.paintColor = new Color(~this.origColor.getRGB());
            }
            g.setColor(this.paintColor);
            BasicGraphicsUtils.drawDashedRect(g, x, y, width, height);
        }
    }
    
    public static class InternalFrameLineBorder extends LineBorder implements UIResource
    {
        protected Color activeColor;
        protected Color inactiveColor;
        
        public InternalFrameLineBorder(Color color, Color inactiveColor, int thickness) {
            super(color, thickness);
            this.activeColor = color;
            this.inactiveColor = inactiveColor;
        }
        
        @Override
        public void paintBorder(Component component, Graphics graphics, int n, int n2, int n3, int n4) {
            JInternalFrame internalFrame;
            if ((component instanceof JInternalFrame)) {
                internalFrame = (JInternalFrame)component;
            }
            else if ((component instanceof JInternalFrame.JDesktopIcon)) {
                internalFrame = ((JInternalFrame.JDesktopIcon)component).getInternalFrame();
            }
            else {
                return;
            }
            if (internalFrame.isSelected()) {
                this.lineColor = this.activeColor;
                super.paintBorder(component, graphics, n, n2, n3, n4);
            }
            else {
                this.lineColor = this.inactiveColor;
                super.paintBorder(component, graphics, n, n2, n3, n4);
            }
        }
    }
}
